AccessListResult

Struct AccessListResult 

pub struct AccessListResult {
    pub access_list: AccessList,
    pub gas_used: Uint<256, 4>,
    pub error: Option<String>,
}
AccessListResult for handling errors from eth_createAccessList

Fields

access_list: AccessList

List with accounts accessed during transaction.

gas_used: Uint<256, 4>

Estimated gas used with access list.

error: Option<String>

Optional error message if the transaction failed.

Implementations

Source

impl AccessListResult

pub fn ensure_ok(self) -> Result<AccessListWithGasUsed, String>

Ensures the result is OK, returning AccessListWithGasUsed if so, or an error message if not.

pub const fn is_err(&self) -> bool

Checks if there is an error in the result.