BlobCellRecoveryError

Enum BlobCellRecoveryError 

pub enum BlobCellRecoveryError {
    InsufficientCells {
        provided: usize,
        required: usize,
    },
    CellCountMismatch {
        provided: usize,
        expected: usize,
    },
    CellCountOverflow,
    CommitmentMismatch {
        blob_index: usize,
    },
    Kzg(Error),
}
Available on crate features kzg-sidecar and kzg only.
An error that can occur while recovering blobs from EIP-7594 cells.

Variants



InsufficientCells

Fewer than half of the extended blob cells were selected.

Fields

provided: usize

The number of cells supplied for each blob.

required: usize

The minimum number of cells required for recovery.



CellCountMismatch

The flattened cell slice does not match the commitments and cell mask.

Fields

provided: usize

The number of cells supplied.

expected: usize

The number of cells implied by the commitments and cell mask.



CellCountOverflow

The expected cell count cannot be represented as a usize.



CommitmentMismatch

A reconstructed blob does not match its supplied commitment.

Fields

blob_index: usize

The index of the blob whose commitment did not match.



Kzg(Error)

An error returned by c_kzg.