BlobSidecarEncoding

Enum BlobSidecarEncoding 

pub enum BlobSidecarEncoding {
    WithBlobs,
    WithoutBlobs,
}
Selects the blob payload representation used when encoding a blob transaction sidecar.

Variants



WithBlobs

Encode the complete sidecar, including its blob payloads.



WithoutBlobs

Encode an empty blob list while retaining commitments and proofs.

This is the sidecar representation used by eth/72 PooledTransactions responses as specified by EIP-8070.