EthForkConfig

Struct EthForkConfig 

pub struct EthForkConfig {
    pub activation_time: u64,
    pub blob_schedule: BlobParams,
    pub chain_id: u64,
    pub fork_id: Bytes,
    pub precompiles: BTreeMap<String, Address>,
    pub system_contracts: BTreeMap<SystemContract, Address>,
}
The fork configuration object as defined by EIP-7910.

Fields

activation_time: u64

The fork activation timestamp, represented as a JSON number in Unix epoch seconds (UTC). For the “current” configuration, this reflects the actual activation time; for “next,” it is the scheduled time. Activation time is required. If a fork is activated at genesis the value 0 is used. If the fork is not scheduled to be activated or its activation time is unknown it should not be in the rpc results.

blob_schedule: BlobParams

The blob configuration parameters for the specific fork, as defined in the genesis file. This is a JSON object with three members — baseFeeUpdateFraction, max, and target — all represented as JSON numbers.

chain_id: u64

The chain ID of the current network, presented as a string with an unsigned 0x-prefixed hexadecimal number, with all leading zeros removed. This specification does not support chains without a chain ID or with a chain ID of zero.

For purposes of canonicalization this value must always be a string.

fork_id: Bytes

The FORK_HASH value as specified in EIP-6122 of the specific fork, presented as an unsigned 0x-prefixed hexadecimal numbers, with zeros left padded to a four byte length, in lower case.

precompiles: BTreeMap<String, Address>

A representation of the active precompile contracts for the fork. If a precompile is replaced by an on-chain contract, or removed, then it is not included.

This is a JSON object where the members are the 20-byte 0x-prefixed hexadecimal addresses of the precompiles (with zeros preserved), and the values are agreed-upon names for each contract, typically specified in the EIP defining that contract.

For Cancun, the contract names are (in order): ECREC, SHA256, RIPEMD160, ID, MODEXP, BN256_ADD, BN256_MUL, BN256_PAIRING, BLAKE2F, KZG_POINT_EVALUATION.

For Prague, the added contracts are (in order): BLS12_G1ADD, BLS12_G1MSM, BLS12_G2ADD, BLS12_G2MSM, BLS12_PAIRING_CHECK, BLS12_MAP_FP_TO_G1, BLS12_MAP_FP2_TO_G2.

system_contracts: BTreeMap<SystemContract, Address>

A JSON object representing system-level contracts relevant to the fork, as introduced in their defining EIPs. Keys are the contract names (e.g., BEACON_ROOTS_ADDRESS) from the first EIP where they appeared, sorted alphabetically. Values are 20-byte addresses in 0x-prefixed hexadecimal form, with leading zeros preserved. Omitted for forks before Cancun.

For Cancun the only system contract is BEACON_ROOTS_ADDRESS.

For Prague the system contracts are (in order) BEACON_ROOTS_ADDRESS, CONSOLIDATION_REQUEST_PREDEPLOY_ADDRESS, DEPOSIT_CONTRACT_ADDRESS, HISTORY_STORAGE_ADDRESS, and WITHDRAWAL_REQUEST_PREDEPLOY_ADDRESS.

Future forks MUST define the list of system contracts in their meta-EIPs.