pub struct BlockAccessListGasError {
pub items: u64,
pub max_items: u64,
pub gas_limit: u64,
}Expand description
Error returned when a block access list item cost exceeds the block gas limit.
Fields
items: u64Number of block access list items.
max_items: u64Maximum number of block access list items allowed by the gas limit.
gas_limit: u64Block gas limit used for validation.
Implementations
Sourceimpl BlockAccessListGasError
impl BlockAccessListGasError
Sourcepub const fn new(items: u64, gas_limit: u64) -> BlockAccessListGasError
pub const fn new(items: u64, gas_limit: u64) -> BlockAccessListGasError
Creates a new gas limit validation error for the provided item count and gas limit.