Module for comparing block access lists. Helpers for finding the first divergence between block access lists.
Structs
- Account
Diff - Account-level details for the first differing BAL entry.
- Account
Field Diff - Per-field difference flags for account entries with the same address.
- Account
Summary - Compact account summary included in
AccountDiff. - BalDiff
- Compact summary of the first difference between two block access lists.
Functions
- first_
bal_ divergence - Returns a compact diff describing the first divergence between two BALs.