AccountFieldDiff

Struct AccountFieldDiff 

pub struct AccountFieldDiff {
    pub storage_changes: bool,
    pub storage_reads: bool,
    pub balance_changes: bool,
    pub nonce_changes: bool,
    pub code_changes: bool,
}
Per-field difference flags for account entries with the same address.

Fields

storage_changes: bool

true if storage_changes differ.

storage_reads: bool

true if storage_reads differ.

balance_changes: bool

true if balance_changes differ.

nonce_changes: bool

true if nonce_changes differ.

code_changes: bool

true if code_changes differ.

Implementations

Source

impl AccountFieldDiff

pub fn new(left: &AccountChanges, right: &AccountChanges) -> AccountFieldDiff

Creates field-level diff flags for account entries with the same address.

pub const fn is_divergent(&self) -> bool

Returns true if any account field differs.