pub struct BlockAccessListHashMismatch {
pub computed: FixedBytes<32>,
pub expected: FixedBytes<32>,
}Expand description
Error returned when a decoded block access list hash does not match the expected hash.
Fields
computed: FixedBytes<32>Hash computed from the received BAL bytes.
expected: FixedBytes<32>Hash expected by the caller, typically header.block_access_list_hash.
Implementations
Sourceimpl BlockAccessListHashMismatch
impl BlockAccessListHashMismatch
Sourcepub const fn new(
computed: FixedBytes<32>,
expected: FixedBytes<32>,
) -> BlockAccessListHashMismatch
pub const fn new( computed: FixedBytes<32>, expected: FixedBytes<32>, ) -> BlockAccessListHashMismatch
Creates a new block access list hash validation error.