pub struct NonceChange {
pub block_access_index: u64,
pub new_nonce: u64,
}Expand description
This struct is used to track the new nonce of accounts in a block.
Fields
block_access_index: u64The index of bal that stores this nonce change.
new_nonce: u64The new code of the account.
Implementations
Sourceimpl NonceChange
impl NonceChange
Sourcepub const fn new(block_access_index: u64, new_nonce: u64) -> NonceChange
pub const fn new(block_access_index: u64, new_nonce: u64) -> NonceChange
Creates a new NonceChange.
Sourcepub const fn block_access_index(&self) -> u64
pub const fn block_access_index(&self) -> u64
Returns the bal index.