SigningFrameSignature

Struct SigningFrameSignature 

pub struct SigningFrameSignature<'a> { /* private fields */ }
Borrowed RLP view of a signature entry in a transaction’s signing preimage.

Created by FrameSignature::as_signing. Its Encodable implementation includes the entry’s list header and applies signature elision independently of the signature scheme.