pub enum BlobCellRecoveryError {
InsufficientCells {
provided: usize,
required: usize,
},
CellCountMismatch {
provided: usize,
expected: usize,
},
CellCountOverflow,
CommitmentMismatch {
blob_index: usize,
},
Kzg(Error),
}Available on crate features
kzg-sidecar and kzg only.Expand description
An error that can occur while recovering blobs from EIP-7594 cells.
Variants
InsufficientCells
Fewer than half of the extended blob cells were selected.
Fields
CellCountMismatch
The flattened cell slice does not match the commitments and cell mask.
Fields
CellCountOverflow
The expected cell count cannot be represented as a usize.
CommitmentMismatch
A reconstructed blob does not match its supplied commitment.
Kzg(Error)
An error returned by c_kzg.