pub struct BlobCellMask { /* private fields */ }kzg-sidecar only.Expand description
Cell indices requested by engine_getBlobsV4.
Implementations
Sourceimpl BlobCellMask
impl BlobCellMask
Sourcepub fn new(indices_bitarray: B128) -> Self
pub fn new(indices_bitarray: B128) -> Self
Creates a mask from the Engine API 16-byte, big-endian bitarray.
Sourcepub const fn contains(self, index: usize) -> bool
pub const fn contains(self, index: usize) -> bool
Returns true if the given cell index is selected.
Sourcepub fn selected_indices(self) -> impl Iterator<Item = usize>
pub fn selected_indices(self) -> impl Iterator<Item = usize>
Iterates selected cell indices in ascending order.
Sourcepub fn matching_cells_from_computed_cells(
self,
cells: &[Cell],
) -> Option<Vec<Cell>>
pub fn matching_cells_from_computed_cells( self, cells: &[Cell], ) -> Option<Vec<Cell>>
Returns the selected cells from precomputed blob-major flattened cells.
The cells slice must use the layout returned by compute_cells: each blob contributes
one contiguous CELLS_PER_EXT_BLOB-cell chunk, so cells.len() must be evenly divisible
by CELLS_PER_EXT_BLOB (128). This method returns None if cells ends with an
incomplete chunk.
The returned cells keep the same chunk order and include only the cell indices selected by this mask.