Module for handling code changes within a block.
Contains the CodeChange struct, which represents a new code for an account.
Single code change: tx_index -> new_code
Structs
- Code
Change - This struct is used to track the new codes of accounts in a block.