pub struct AccountFieldDiff {
pub storage_changes: bool,
pub storage_reads: bool,
pub balance_changes: bool,
pub nonce_changes: bool,
pub code_changes: bool,
}Expand description
Per-field difference flags for account entries with the same address.
Fields
storage_changes: booltrue if storage_changes differ.
storage_reads: booltrue if storage_reads differ.
balance_changes: booltrue if balance_changes differ.
nonce_changes: booltrue if nonce_changes differ.
code_changes: booltrue if code_changes differ.
Implementations
Sourceimpl AccountFieldDiff
impl AccountFieldDiff
Sourcepub fn new(left: &AccountChanges, right: &AccountChanges) -> AccountFieldDiff
pub fn new(left: &AccountChanges, right: &AccountChanges) -> AccountFieldDiff
Creates field-level diff flags for account entries with the same address.
Sourcepub const fn is_divergent(&self) -> bool
pub const fn is_divergent(&self) -> bool
Returns true if any account field differs.